pipesnake package
=================

Subpackages
-----------

.. toctree::

    pipesnake.base
    pipesnake.pipe
    pipesnake.transformers
    pipesnake.utils

Submodules
----------

pipesnake\.metadata module
--------------------------

.. automodule:: pipesnake.metadata
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pipesnake
    :members:
    :undoc-members:
    :show-inheritance:
